@@ -17,8 +17,9 @@
 # 2013-07-01: New 'constants' argument for use when called from within a function.
 # 2013-07-18: fixed a bug in passing the 'func' argument
 # 2016-03-31: added level argument and report CIs. J. Fox
-# 2017-11-09: make compatible with vcov() in R 3.5.0. J. Fox
-# 2017-11-13: further fixes for vcov(). J. Fox
+# 2017-11-09: made compatible with vcov() in R 2.5.0. J. Fox
+# 2017-11-29: further fixes for vcov() and vcov.(). J. Fox
+# 2017-12-01: fix bug in handling vcov. arg in some methods. J. Fox
 #-------------------------------------------------------------------------------
 
 deltaMethod <- function (object, ...) {
@@ -78,20 +79,21 @@ deltaMethod.lm <- function (object, g, vcov. = vcov(object, complete=FALSE),
 }
 
 # nls has named parameters so parameterNames is ignored
-deltaMethod.nls <- function(object, g, vcov.=vcov(object, complete=FALSE),...){
-	vcov. <- if(is.function(vcov.)) vcov.(object)
+deltaMethod.nls <- function(object, g, vcov.=vcov(object, complete=FALSE), ...){
+	vcov. <- if(is.function(vcov.)) vcov.(object) else vcov.
 	deltaMethod.default(coef(object), g, vcov., ...)   
 }
 
-deltaMethod.polr <- function(object, g, vcov.=vcov,...){
+deltaMethod.polr <- function(object,g,vcov.=vcov(object, complete=FALSE), ...){
 	sel <- 1:(length(coef(object)))
-	vcov. <- if(is.function(vcov.)) vcov.(object)[sel, sel]
+	vcov. <- if(is.function(vcov.)) vcov.(object)[sel, sel] else vcov.[sel, sel]
 	deltaMethod.lm(object, g, vcov., ...)
 }
 
-deltaMethod.multinom <- function(object, g, vcov.=vcov, 
+deltaMethod.multinom <- function(object, g, vcov.=vcov(object, complete=FALSE), 
    parameterNames = if(is.matrix(coef(object)))
      colnames(coef(object)) else names(coef(object)), ...){
+  vcov. <- if(is.function(vcov.)) vcov.(object) else vcov.
 	out <- NULL
 	coefs <- coef(object)
 	if (!is.matrix(coefs)) { coefs <- t(as.matrix(coefs)) }
@@ -99,7 +101,7 @@ deltaMethod.multinom <- function(object, g, vcov.=vcov,
 	nc <- dim(coefs)[2]
 	for (i in 1:dim(coefs)[1]){
 		para <- coefs[i, ]
-		ans <- deltaMethod(para, g, vcov.(object)[(i - 1) + 1:nc, (i - 1) + 1:nc], ...)
+		ans <- deltaMethod(para, g, vcov.[(i - 1) + 1:nc, (i - 1) + 1:nc], ...)
 		rownames(ans)[1] <- paste(rownames(coefs)[i], rownames(ans)[1])
 		out <- rbind(out,ans)
 	}
