@@ -23,6 +23,7 @@
 # 2017-12-28: rewrote termsToMf used by residualPlots.  It didn't work right.  SW
 # 2018-01-15: df.terms.multinom() now works with response matrix. JF
 # 2018-05-23: make model.matrix.lme() more bullet proof, following report by Peter Grossmann. JF
+# 2018-08-23: temporarily add askYesNo()
 
 #if (getRversion() >= "2.15.1") globalVariables(c(".boot.sample", ".boot.indices"))
 
@@ -455,3 +456,36 @@ carPalette <- carPal()
 format.perc <- function (probs, digits){
   paste(format(100 * probs, trim = TRUE, scientific = FALSE, digits = digits), "%")
 }
+
+# the following function is copied from the utils package and is intended only for car 3.0-2
+
+askYesNo <- function (msg, default = TRUE, prompts = getOption("askYesNo", 
+                                                   gettext(c("Yes", "No", "Cancel"))), ...) 
+{
+    if (is.character(prompts) && length(prompts) == 1) 
+        prompts <- strsplit(prompts, "/")[[1]]
+    if (!is.character(prompts) || length(prompts) != 3) {
+        fn <- match.fun(prompts)
+        return(fn(msg = msg, default = default, prompts = prompts, 
+                  ...))
+    }
+    choices <- tolower(prompts)
+    if (is.na(default)) 
+        choices[3L] <- prompts[3L]
+    else if (default) 
+        choices[1L] <- prompts[1L]
+    else choices[2L] <- prompts[2L]
+    msg1 <- paste0("(", paste(choices, collapse = "/"), ") ")
+    if (nchar(paste0(msg, msg1)) > 250) {
+        cat(msg, "\n")
+        msg <- msg1
+    }
+    else msg <- paste0(msg, " ", msg1)
+    ans <- readline(msg)
+    match <- pmatch(tolower(ans), tolower(choices))
+    if (!nchar(ans)) 
+        default
+    else if (is.na(match)) 
+        stop("Unrecognized response ", dQuote(ans))
+    else c(TRUE, FALSE, NA)[match]
+}
